pub struct DeliveryArea {
pub code: String,
pub code_type: i32,
}Expand description
DeliveryArea represents the geographical or administrative region, usually defined and maintained by a Transmission System Operator (TSO), where electricity deliveries for a contract occur.
The concept is important to energy trading as it delineates the agreed-upon delivery location. Delivery areas can have different codes based on the// jurisdiction in which they operate.
!!! note “Jurisdictional Differences” This is typically represented by specific codes according to local jurisdiction. In Europe, this is represented by an EIC (Energy Identification Code).
Fields
code: StringCode representing the unique identifier for the delivery area.
code_type: i32Type of code used for identifying the delivery area itself.
Implementations
Sourceimpl DeliveryArea
impl DeliveryArea
Sourcepub fn code_type(&self) -> EnergyMarketCodeType
pub fn code_type(&self) -> EnergyMarketCodeType
Returns the enum value of code_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_code_type(&mut self, value: EnergyMarketCodeType)
pub fn set_code_type(&mut self, value: EnergyMarketCodeType)
Sets code_type to the provided enum value.