ElectricalComponentStateCode

Enum ElectricalComponentStateCode 

#[repr(i32)]
pub enum ElectricalComponentStateCode {
Show 21 variants Unspecified = 0, Unknown = 1, Unavailable = 2, SwitchingOff = 3, Off = 4, SwitchingOn = 5, Standby = 6, Ready = 7, Charging = 8, Discharging = 9, Error = 10, EvChargingCableUnplugged = 20, EvChargingCablePluggedAtStation = 21, EvChargingCablePluggedAtEv = 22, EvChargingCableLockedAtStation = 23, EvChargingCableLockedAtEv = 24, RelayOpen = 30, RelayClosed = 31, PrechargerOpen = 40, PrechargerPrecharging = 41, PrechargerClosed = 42,
}
Enum to represent the various states that a component can be in. This enum is unified across all component categories for consistency.

Variants



Unspecified = 0

Default value when the component state is not explicitly set. This is the zero value of the enum.



Unknown = 1

State when the component is in an unknown or undefined condition. This is used when the sender is unable to classify the component into any other state.



Unavailable = 2

State when the component is temporarily unavailable for operation.



SwitchingOff = 3

State when the component is in the process of switching off.



Off = 4

State when the component has successfully switched off.



SwitchingOn = 5

State when the component is in the process of switching on from an off state.



Standby = 6

State when the component is in standby mode, and not immediately ready for immediate operations.



Ready = 7

State when the component is fully operational and ready for use.



Charging = 8

State when the component is actively consuming energy.



Discharging = 9

State when the component is actively producing or releasing energy.



Error = 10

State when the component is in an error state and may need attention.



EvChargingCableUnplugged = 20

The Electric Vehicle (EV) charging cable is unplugged from the charging station.



EvChargingCablePluggedAtStation = 21

The EV charging cable is plugged into the charging station.



EvChargingCablePluggedAtEv = 22

The EV charging cable is plugged into the vehicle.



EvChargingCableLockedAtStation = 23

The EV charging cable is locked at the charging station end, indicating readiness for charging.



EvChargingCableLockedAtEv = 24

The EV charging cable is locked at the vehicle end, indicating that charging is active.



RelayOpen = 30

The relay is in an open state, meaning no current can flow through.



RelayClosed = 31

The relay is in a closed state, allowing current to flow.



PrechargerOpen = 40

The precharger circuit is open, meaning it’s not currently active.



PrechargerPrecharging = 41

The precharger is in a precharging state, preparing the main circuit for activation.



PrechargerClosed = 42

The precharger circuit is closed, allowing full current to flow to the main circuit.

Implementations

Source

impl ElectricalComponentStateCode

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of ElectricalComponentStateCode.

pub fn from_i32(value: i32) -> Option<ElectricalComponentStateCode>

👎Deprecated:

Use the TryFrom<i32> implementation instead

Converts an i32 to a ElectricalComponentStateCode, or None if value is not a valid variant.

Source

impl ElectricalComponentStateCode

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<Self>

Creates an enum from field names used in the ProtoBuf definition.