pub struct Battery {
pub type: i32,
}Expand description
A representation of a battery.
Fields
type: i32The battery type.
Implementations
Sourceimpl Battery
impl Battery
Sourcepub fn type(&self) -> BatteryType
pub fn type(&self) -> BatteryType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: BatteryType)
pub fn set_type(&mut self, value: BatteryType)
Sets type to the provided enum value.