pub struct ElectricalComponentTelemetry {
pub electrical_component_id: u64,
pub metric_samples: Vec<MetricSample>,
pub state_snapshots: Vec<ElectricalComponentStateSnapshot>,
}Expand description
ElectricalComponentTelemetry message aggregates multiple metrics, operational states, and errors, related to a specific electrical component in a microgrid.
!!! example Example output of a telemetry message: ``` { electrical_component_id: 13, metric_samples: [ /* list of metrics for multiple timestamps / { sample_time: “2023-10-01T00:00:00Z”, metric: “DC_VOLTAGE_V”, value: {}, bounds: {}, connection: “battery_0” }, { sample_time: “2023-10-01T00:00:00Z”, metric: “DC_VOLTAGE_V”, value: {}, bounds: {}, connection: “pv_0” } ], state_snapshots: [ / list of states for multiple timestamps */ { sample_time: “2023-10-01T00:00:00Z”, states: [], warnings: [], errors: [], }, { sample_time: “2023-10-01T00:00:00Z”, states: [], warnings: [], errors: [], }, ] }
Fields
electrical_component_id: u64The ID of the electrical component for which the telemetry is collected.
metric_samples: Vec<MetricSample>List of measurements for a metric of the specific electrical component.
state_snapshots: Vec<ElectricalComponentStateSnapshot>List of state snapshots of a specific electrical component.