GridConnectionPoint

Struct GridConnectionPoint 

pub struct GridConnectionPoint {
    pub rated_fuse_current: u32,
}
A representation of a grid connection point. This is the point where a microgrid connects to the grid.

The terms “Grid Connection Point” and “Point of Common Coupling” (PCC) are commonly used in the context.

While both terms describe a connection point to the grid, the GridConnectionPoint is specifically the physical connection point of the generation facility to the grid, often concerned with the technical and ownership aspects of the connection.

In contrast, the PCC is is more specific in terms of electrical engineering. It refers to the point where a customer’s local electrical system (such as a microgrid) connects to the utility distribution grid in such a way that it can affect other customers’ systems connected to the same network. It is the point where the grid and customer’s electrical systems interface and where issues like power quality and supply regulations are assessed.

The term GridConnectionPoint is used to make it clear that what is referred to here is the physical connection point of the local facility to the grid. Note that this may also be the PCC in some cases.

Fields

rated_fuse_current: u32

This refers to the maximum amount of electrical current, in amperes, that a fuse at the grid connection point is designed to safely carry under normal operating conditions.

This limit applies to currents both flowing in or out of each of the 3 phases individually.

In other words, a current i A at one of the phases of the grid connection point must comply with the following constraint: -rated_fuse_current <= i <= rated_fuse_current