pub struct Inverter {
pub type: i32,
}Expand description
A representation of an inverter. The inverter metadata.
Fields
type: i32The inverter type.
Implementations
Sourceimpl Inverter
impl Inverter
Sourcepub fn type(&self) -> InverterType
pub fn type(&self) -> InverterType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: InverterType)
pub fn set_type(&mut self, value: InverterType)
Sets type to the provided enum value.