PowerTransformer

Struct PowerTransformer 

pub struct PowerTransformer {
    pub primary: f32,
    pub secondary: f32,
}
A representation of a power transformer.

The voltage across the secondary winding of a power transformer is typically equal to the voltage across the primary winding multiplied by the primary/secondary turns ratio. The current flowing through the secondary winding is typically equal to the current flowing through the primary winding multiplied by the secondary/primary turns ratio, ignoring losses.

If the voltage across the secondary winding is greater than the voltage across the primary winding, the transformer is said to step-up the voltage, otherwise it is said to step-down the voltage.

Fields

primary: f32

The primary voltage of the transformer. This is the input voltage that is stepped up or down.

secondary: f32

The secondary voltage of the transformer. This is the output voltage that is the result of stepping the primary voltage up or down.