#[repr(i32)]pub enum SensorStateCode {
Unspecified = 0,
Ok = 1,
Error = 2,
}Expand description
Enum to represent the various states that a sensor can be in. This enum is unified across all sensor categories for consistency.
Variants
Unspecified = 0
Default value when the sensor state is not explicitly set. This is the zero value of the enum.
Ok = 1
The sensor is up and running.
Error = 2
The sensor is in an error state.
Implementations
Sourceimpl SensorStateCode
impl SensorStateCode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.