Lifetime

Struct Lifetime 

pub struct Lifetime {
    pub start_timestamp: Option<Timestamp>,
    pub end_timestamp: Option<Timestamp>,
}
Lifetime captures the timestamps indicating the active operational period of a microgrid asset, such as a component, connection, sensor, or any other entity with a limited operational lifetime.

It is normally used to track the historical evolution of assets, and it determines the validity period for the asset’s data.

If the start_timestamp is not set, the asset is considered to be in operation since the beginning of the system’s operational history.

If the end_timestamp is not set, the asset is considered to be in operation indefinitely into the future.

If the Lifetime message is completely missing, it means both timestamps are not set, which means the asset is considered to be in operation since the beginning of the system’s operational history and indefinitely into the future.

Fields

start_timestamp: Option<Timestamp>

The timestamp when the asset became operationally active. If not set, the asset is considered to be in operation since the beginning of the system’s operational history.

end_timestamp: Option<Timestamp>

Optional timestamp when the asset’s operational activity ceased. If not set, the asset is considered to be in operation indefinitely into the future.