pub struct Microgrid {
pub id: u64,
pub enterprise_id: u64,
pub name: String,
pub delivery_area: Option<DeliveryArea>,
pub location: Option<Location>,
pub status: i32,
pub create_timestamp: Option<Timestamp>,
}Expand description
Microgrid contains details of a specific microgrid. A microgrid is a localized grouping of electricity generation, energy storage, and loads that normally operates connected to a traditional centralized grid. Each microgrid has a unique identifier and is associated with an enterprise account. A key feature is that it has a physical location and is situated in a delivery area.
!!! info “Key Concepts”
Physical Location: Geographical coordinates specify the exact physical location of the microgrid.Delivery Area: Each microgrid is part of a broader delivery area, which is crucial for energy trading and compliance.
Fields
id: u64Unique identifier of the microgrid.
enterprise_id: u64Unique identifier linking this microgrid to its parent enterprise account.
name: StringName of the microgrid.
delivery_area: Option<DeliveryArea>The delivery area where the microgrid is located, as identified by a specific code.
If a microgrid is not connected to the grid (it is an island) it does not belong to any delivery area and this field will be missing, but it could be missing for other reasons as well.
location: Option<Location>Physical location of the microgrid, in geographical co-ordinates.
If the location is not known, this field will be missing.
status: i32The current status of the microgrid.
create_timestamp: Option<Timestamp>The UTC timestamp indicating when the microgrid was initially created.
Implementations
Sourceimpl Microgrid
impl Microgrid
Sourcepub fn status(&self) -> MicrogridStatus
pub fn status(&self) -> MicrogridStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: MicrogridStatus)
pub fn set_status(&mut self, value: MicrogridStatus)
Sets status to the provided enum value.