#[repr(i32)]pub enum PowerType {
Unspecified = 0,
Active = 1,
Reactive = 2,
}Expand description
The type of power requested for an electrical component.
Variants
Unspecified = 0
Default value. Users are discouraged from using this value. Using this will result in an error.
Active = 1
The requested power is active power.
Reactive = 2
The requested power is reactive power.
Implementations
Sourceimpl PowerType
impl PowerType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.