SetElectricalComponentPowerRequestStatus

Enum SetElectricalComponentPowerRequestStatus 

#[repr(i32)]
pub enum SetElectricalComponentPowerRequestStatus { Unspecified = 0, Accepted = 1, Rejected = 2, Failed = 3, Success = 4, Overridden = 5, }
Response codes for the SetElectricalComponentPowerActive and SetElectricalComponentPowerReactive RPCs. These codes indicate the ongoing status of the request to set the power of an electrical component.

Often, electrical components are not able to immediately set their output power to the requested value. This can happen due to several reasons, including, but not limited to:

  • having to ramp up or down the power output from the current output.
  • having to wait for the electrical component to reach a stable state before applying the new power set-point.
  • communication latency between the API service and the electrical component.

In such cases, an initial response is sent to the client, indicating that the request has been accepted, and it is followed by a stream of responses indicating the ongoing status of the request.

Variants



Unspecified = 0

Default value. Users are discouraged from using this value.



Accepted = 1

The request has been accepted, and the target power set-point will be applied to the electrical component.

Once the API service has received a request to set the power of an electrical component, it will validate the input parameters immediately. If the parameters are valid, the service will return this code immediately, and then proceed to apply the power set-point to the electrical component.



Rejected = 2

The request has been rejected because of invalid input parameters.

Once the API service has received a request to set the power of an electrical component, it will validate the input parameters immediately. If the parameters are invalid, the service will return this code immediately, and will not apply the power set-point to the electrical component.



Failed = 3

The request has failed midway, and the electrical component is not at the desired power level.

This code indicates that the request to set the power of an electrical component has been accepted, but the service encountered an error while applying the power set-point to the electrical component.



Success = 4

The request has been successfully processed.



Overridden = 5

The request has been overridden by another request.

This could happen if a new request to set the power of an electrical component arrives while the previous request is still being processed.

Implementations

Source

impl SetElectricalComponentPowerRequestStatus

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of SetElectricalComponentPowerRequestStatus.

pub fn from_i32(value: i32) -> Option<SetElectricalComponentPowerRequestStatus>

👎Deprecated:

Use the TryFrom<i32> implementation instead

Converts an i32 to a SetElectricalComponentPowerRequestStatus, or None if value is not a valid variant.

Source

impl SetElectricalComponentPowerRequestStatus

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<Self>

Creates an enum from field names used in the ProtoBuf definition.