pub struct AugmentElectricalComponentBoundsRequest {
pub electrical_component_id: u64,
pub target_metric: i32,
pub bounds: Vec<Bounds>,
pub request_lifetime: Option<u64>,
}Expand description
Request parameters for the RPC AugmentElectricalComponentBounds.
Fields
electrical_component_id: u64The ID of the target electrical component.
target_metric: i32The target metric whose bounds have to be set.
bounds: Vec<Bounds>A list of bounds for the target metric. While incorporating these bounds, the API will ensure that overlapping pairs of bounds are merged into a single pair of bounds, and non-overlapping ones are kept separated.
request_lifetime: Option<u64>The duration, in seconds, until which the request will stay in effect. This duration has to be between 5 seconds and 15 minutes (including both limits), otherwise the request will be rejected. If not provided, it defaults to 5s.
Implementations
Sourceimpl AugmentElectricalComponentBoundsRequest
impl AugmentElectricalComponentBoundsRequest
Sourcepub fn target_metric(&self) -> Metric
pub fn target_metric(&self) -> Metric
Returns the enum value of target_metric, or the default if the field is set to an invalid enum value.
Sourcepub fn set_target_metric(&mut self, value: Metric)
pub fn set_target_metric(&mut self, value: Metric)
Sets target_metric to the provided enum value.
Sourcepub fn request_lifetime(&self) -> u64
pub fn request_lifetime(&self) -> u64
Returns the value of request_lifetime, or the default value if request_lifetime is unset.