pub struct ReceiveElectricalComponentTelemetryStreamRequest {
pub electrical_component_id: u64,
pub filter: Option<ComponentTelemetryStreamFilter>,
}Expand description
Request parameters for the RPC ReceiveElectricalComponentTelemetryStream.
Fields
electrical_component_id: u64The electrical component ID to subscribe to.
filter: Option<ComponentTelemetryStreamFilter>The filter to apply to the stream.
This field is optional. If this is not provided, then the stream will return all metrics for the given electrical component. If this is provided, then the stream will return only the metrics specified in the filter.