pub struct ReceiveSensorTelemetryStreamRequest {
pub sensor_id: u64,
pub filter: Option<SensorTelemetryStreamFilter>,
}Expand description
Request parameters for the RPC ReceiveSensorTelemetryStream.
Fields
sensor_id: u64The sensor ID to subscribe to.
filter: Option<SensorTelemetryStreamFilter>The filter to apply to the stream.
This field is optional. If this is not provided, then the stream will return all metrics for the given sensor. If this is provided, then the stream will return only the metrics specified in the filter.