pub struct SetElectricalComponentPowerResponse {
pub valid_until_time: Option<Timestamp>,
pub status: i32,
}Expand description
Response message for the RPC SetElectricalComponentPower.
Fields
valid_until_time: Option<Timestamp>The timestamp until which the given power command will stay in effect. After this timestamp, the electrical component will be set to its standby state, if the API receives no further power commands. By default, this timestamp will be set to the current time plus 60 seconds.
When the request status is REJECTED, FAILED, or OVERRIDDEN, the
valid_until_time timestamp will not be set, and the request will no
longer remain in effect.
status: i32The current status of the request to set the power of the electrical component.
Implementations
Sourceimpl SetElectricalComponentPowerResponse
impl SetElectricalComponentPowerResponse
Sourcepub fn status(&self) -> SetElectricalComponentPowerRequestStatus
pub fn status(&self) -> SetElectricalComponentPowerRequestStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: SetElectricalComponentPowerRequestStatus)
pub fn set_status(&mut self, value: SetElectricalComponentPowerRequestStatus)
Sets status to the provided enum value.