pub struct ElectricalComponent {
pub id: u64,
pub microgrid_id: u64,
pub name: String,
pub category: i32,
pub category_specific_info: Option<ElectricalComponentCategorySpecificInfo>,
pub manufacturer: String,
pub model_name: String,
pub operational_lifetime: Option<Lifetime>,
pub metric_config_bounds: Vec<MetricConfigBounds>,
}Expand description
Microgrid electrical component details.
Fields
id: u64The component ID.
microgrid_id: u64Unique identifier of the parent microgrid_id.
name: StringThe component name.
category: i32The component category. E.g., Inverter, Battery, etc.
category_specific_info: Option<ElectricalComponentCategorySpecificInfo>The metadata specific to the component category type.
manufacturer: StringThe component manufacturer.
model_name: StringThe model name of the component.
operational_lifetime: Option<Lifetime>The operational lifetime of the component.
metric_config_bounds: Vec<MetricConfigBounds>List of rated bounds present for the component identified by Metric.
Implementations
Sourceimpl ElectricalComponent
impl ElectricalComponent
Sourcepub fn category(&self) -> ElectricalComponentCategory
pub fn category(&self) -> ElectricalComponentCategory
Returns the enum value of category, or the default if the field is set to an invalid enum value.
Sourcepub fn set_category(&mut self, value: ElectricalComponentCategory)
pub fn set_category(&mut self, value: ElectricalComponentCategory)
Sets category to the provided enum value.
Sourceimpl ElectricalComponent
impl ElectricalComponent
Sourcepub fn is_inverter(&self) -> bool
pub fn is_inverter(&self) -> bool
Returns true if the component is an inverter, false otherwise.
Sourcepub fn is_pv_inverter(&self) -> bool
pub fn is_pv_inverter(&self) -> bool
Returns true if the component is a PV inverter, false otherwise.
Sourcepub fn is_battery_inverter(&self) -> bool
pub fn is_battery_inverter(&self) -> bool
Returns true if the component is a battery inverter, false otherwise.
Sourcepub fn is_hybrid_inverter(&self) -> bool
pub fn is_hybrid_inverter(&self) -> bool
Returns true if the component is a hybrid inverter, false otherwise.