pub struct BatteryPool { /* private fields */ }Expand description
An interface for abstracting over a pool of batteries in the microgrid.
Implementations
Sourceimpl BatteryPool
impl BatteryPool
Sourcepub fn power(&mut self) -> Result<Formula<Power>, Error>
pub fn power(&mut self) -> Result<Formula<Power>, Error>
Returns a formula for the active power of the battery pool.
Sourcepub fn power_bounds(&mut self) -> Receiver<Vec<Bounds<Power>>>
pub fn power_bounds(&mut self) -> Receiver<Vec<Bounds<Power>>>
Returns a receiver for the aggregated active-power bounds of the pool, updated on each snapshot.
Reuses the running bounds tracker if one exists and still has active receivers; otherwise starts a new one (which also starts or reuses the underlying telemetry tracker).