Bounds

Struct Bounds 

pub struct Bounds<Q: Quantity> { /* private fields */ }
A set of lower and upper bounds for any metric.

Implementations

Source

impl<Q: Quantity> Bounds<Q>

pub fn new(lower: Option<Q>, upper: Option<Q>) -> Self

Creates a new Bounds with the given lower and upper bounds.

pub fn lower(&self) -> Option<Q>

Returns the lower bound.

pub fn upper(&self) -> Option<Q>

Returns the upper bound.

pub fn combine_parallel(&self, other: &Self) -> Vec<Self>

Combines two bounds as if their components were connected in parallel.

pub fn intersect(&self, other: &Self) -> Option<Self>

Returns the intersection of self and other, or None if the intersection is empty.

pub fn merge_if_overlapping(&self, other: &Self) -> Option<Self>

If self and other overlap, returns the smallest single interval that contains both; otherwise returns None.