pub struct InverterBatteryGroup {
pub inverter_ids: BTreeSet<u64>,
pub battery_ids: BTreeSet<u64>,
}Expand description
A set of inverters and batteries wired together in an MxN configuration:
M inverters in parallel on the AC side, N batteries in parallel on the DC
side, with the inverter side in series with the battery side.
Fields
inverter_ids: BTreeSet<u64>battery_ids: BTreeSet<u64>Trait Implementations
Sourceimpl Clone for InverterBatteryGroup
impl Clone for InverterBatteryGroup
Sourcefn clone(&self) -> InverterBatteryGroup
fn clone(&self) -> InverterBatteryGroup
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InverterBatteryGroup
impl Debug for InverterBatteryGroup
impl Eq for InverterBatteryGroup
Sourceimpl Hash for InverterBatteryGroup
impl Hash for InverterBatteryGroup
Sourceimpl PartialEq for InverterBatteryGroup
impl PartialEq for InverterBatteryGroup
Sourcefn eq(&self, other: &InverterBatteryGroup) -> bool
fn eq(&self, other: &InverterBatteryGroup) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for InverterBatteryGroup