pub struct LogicalMeterHandle { /* private fields */ }Expand description
This provides an interface stream high-level metrics from a microgrid.
Implementations
Sourceimpl LogicalMeterHandle
impl LogicalMeterHandle
Sourcepub async fn try_new(
client: MicrogridClientHandle,
config: LogicalMeterConfig,
) -> Result<Self, Error>
pub async fn try_new( client: MicrogridClientHandle, config: LogicalMeterConfig, ) -> Result<Self, Error>
Creates a new LogicalMeter instance.
Listing the components and connections from the API and building the
component graph is retried indefinitely with a 3 second backoff, so
this call blocks until the server is reachable and returns data that
forms a valid graph. Returns an error only if config is invalid.
Sourcepub fn grid<M: Metric>(&self) -> Result<Formula<M::QuantityType>, Error>
pub fn grid<M: Metric>(&self) -> Result<Formula<M::QuantityType>, Error>
Returns a receiver that streams samples for the given metric at the grid
connection point.
Sourcepub fn battery<M: Metric>(
&self,
component_ids: Option<BTreeSet<u64>>,
) -> Result<Formula<M::QuantityType>, Error>
pub fn battery<M: Metric>( &self, component_ids: Option<BTreeSet<u64>>, ) -> Result<Formula<M::QuantityType>, Error>
Returns a receiver that streams samples for the given metric for the
given battery IDs.
When component_ids is None, all batteries in the microgrid are used.
Sourcepub fn chp<M: Metric>(
&self,
component_ids: Option<BTreeSet<u64>>,
) -> Result<Formula<M::QuantityType>, Error>
pub fn chp<M: Metric>( &self, component_ids: Option<BTreeSet<u64>>, ) -> Result<Formula<M::QuantityType>, Error>
Returns a receiver that streams samples for the given metric for the
given CHP IDs.
When component_ids is None, all CHPs in the microgrid are used.
Sourcepub fn pv<M: Metric>(
&self,
component_ids: Option<BTreeSet<u64>>,
) -> Result<Formula<M::QuantityType>, Error>
pub fn pv<M: Metric>( &self, component_ids: Option<BTreeSet<u64>>, ) -> Result<Formula<M::QuantityType>, Error>
Returns a receiver that streams samples for the given metric for the
given PV IDs.
When component_ids is None, all PVs in the microgrid are used.
Sourcepub fn ev_charger<M: Metric>(
&self,
component_ids: Option<BTreeSet<u64>>,
) -> Result<Formula<M::QuantityType>, Error>
pub fn ev_charger<M: Metric>( &self, component_ids: Option<BTreeSet<u64>>, ) -> Result<Formula<M::QuantityType>, Error>
Returns a receiver that streams samples for the given metric for the
given EV charger IDs.
When component_ids is None, all EV chargers in the microgrid are
used.
Sourcepub fn consumer<M: Metric>(&self) -> Result<Formula<M::QuantityType>, Error>
pub fn consumer<M: Metric>(&self) -> Result<Formula<M::QuantityType>, Error>
Returns a receiver that streams samples for the given metric for the
logical consumer in the microgrid.
Sourcepub fn producer<M: Metric>(&self) -> Result<Formula<M::QuantityType>, Error>
pub fn producer<M: Metric>(&self) -> Result<Formula<M::QuantityType>, Error>
Returns a receiver that streams samples for the given metric for the
logical producer in the microgrid.
Sourcepub fn component<M: Metric>(
&self,
component_id: u64,
) -> Result<Formula<M::QuantityType>, Error>
pub fn component<M: Metric>( &self, component_id: u64, ) -> Result<Formula<M::QuantityType>, Error>
Returns a receiver that streams samples for the given metric for the
given component ID.
Sourcepub fn graph(
&self,
) -> &ComponentGraph<ElectricalComponent, ElectricalComponentConnection>
pub fn graph( &self, ) -> &ComponentGraph<ElectricalComponent, ElectricalComponentConnection>
Returns a reference to the component graph.