High-level interface for the Microgrid API.
Re-exports
pub use client::MicrogridClientHandle;
Modules
- client
- A clonable client for the microgrid API.
- metric
- Metrics supported by the logical meter.
- quantity
- This module defines various physical quantities and their operations.
Structs
- Bounds
- A set of lower and upper bounds for any metric.
- Error
- An error that can occur during the creation or traversal of a [ComponentGraph][crate::ComponentGraph].
- Logical
Meter Config - Logical
Meter Handle - This provides an interface stream high-level metrics from a microgrid.
- Sample
- Represents a measurement of a microgrid metric, made at a specific time.