pub struct ElectricalComponentConnection {
pub source_electrical_component_id: u64,
pub destination_electrical_component_id: u64,
pub operational_lifetime: Option<Lifetime>,
}Expand description
ElectricalComponentConnection describes a single electrical link between two components within a microgrid, effectively representing the physical wiring as viewed from the grid connection point, if one exists, or from the islanding point, in case of an islanded microgrids.
!!! note “Physical Representation” This message is not about data flow but rather about the physical electrical connections between components. Therefore, the IDs for the source and destination components correspond to the actual setup within the microgrid.
!!! note “Direction” The direction of the connection follows the flow of current away from the grid connection point, or in case of islands, away from the islanding point. This direction is aligned with positive current according to the [Passive Sign Convention] (https://en.wikipedia.org/wiki/Passive_sign_convention).
!!! info “Historical Data” The timestamps of when a connection was created and terminated allows for tracking the changes over time to a microgrid, providing insights into when and how the microgrid infrastructure has been modified.
Fields
source_electrical_component_id: u64Unique identifier of the component where the connection originates. This is aligned with the direction of current flow away from the grid connection point, or in case of islands, away from the islanding point.
destination_electrical_component_id: u64Unique ID of the component where the connection terminates. This is the component towards which the current flows.
operational_lifetime: Option<Lifetime>The operational lifetime of the connection.