pub struct ElectricalComponentStateSnapshot {
pub origin_time: Option<Timestamp>,
pub states: Vec<i32>,
pub warnings: Vec<ElectricalComponentDiagnostic>,
pub errors: Vec<ElectricalComponentDiagnostic>,
}Expand description
Representation of a component state, warnings, and errors.
Fields
origin_time: Option<Timestamp>The UTC time when the state was originally captured.
states: Vec<i32>List of operational states currently active for the component.
!!! note This list is treated as a set, and therefore its members will be unique, i.e., no state will exist twice in this list.
!!! note
If the state is ELECTRICAL_COMPONENT_STATE_CODE_ERROR, then the
electrical component is in an error state. In such cases, the errors
field will be populated with the list of errors.
warnings: Vec<ElectricalComponentDiagnostic>List of non-critical warnings detected for the component.
!!! note This list is treated as a set, and therefore its members will be unique, i.e., no state will exist twice in this list.
!!! note Warnings may be reported even when the component is operational.
errors: Vec<ElectricalComponentDiagnostic>List of critical errors currently affecting the component.
!!! note This list is treated as a set, and therefore its members will be unique, i.e., no state will exist twice in this list.
!!! note This list is expected to have errors if and only if the electrical component is in an error state.
Implementations
Sourceimpl ElectricalComponentStateSnapshot
impl ElectricalComponentStateSnapshot
Sourcepub fn states(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<ElectricalComponentStateCode>>
pub fn states( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<ElectricalComponentStateCode>>
Returns an iterator which yields the valid enum values contained in states.
Sourcepub fn push_states(&mut self, value: ElectricalComponentStateCode)
pub fn push_states(&mut self, value: ElectricalComponentStateCode)
Appends the provided enum value to states.