pub struct SetElectricalComponentPowerRequest {
pub electrical_component_id: u64,
pub power_type: i32,
pub power: f32,
pub request_lifetime: Option<u64>,
}Expand description
Request parameters for the RPC SetElectricalComponentPower.
Fields
electrical_component_id: u64The ID of the electrical component to set the output power of.
power_type: i32The requested power type.
power: f32The requested power output.
For Active power:
- This value is in watts (W).
- Negative values indicate discharge, i.e., supplying power towards the direction of the root node of the component graph.
- Positive values indicate charge, i.e., consuming power from the direction of the root node of the component graph.
For Reactive power:
- This value is in volt-amperes reactive (VAR).
- Negative values indicate capacitive reactive power, i.e., the current is leading the voltage when viewed from the perspective of the electrical component.
- Positive values indicate inductive reactive power, i.e., the current is lagging the voltage when viewed from the perspective of the electrical component.
request_lifetime: Option<u64>The duration, in seconds, until which the request will stay in effect. This duration has to be between 10 seconds and 15 minutes (including both limits), otherwise the request will be rejected. If not provided, it defaults to 60s.
Implementations
Sourceimpl SetElectricalComponentPowerRequest
impl SetElectricalComponentPowerRequest
Sourcepub fn power_type(&self) -> PowerType
pub fn power_type(&self) -> PowerType
Returns the enum value of power_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_power_type(&mut self, value: PowerType)
pub fn set_power_type(&mut self, value: PowerType)
Sets power_type to the provided enum value.
Sourcepub fn request_lifetime(&self) -> u64
pub fn request_lifetime(&self) -> u64
Returns the value of request_lifetime, or the default value if request_lifetime is unset.