pub struct Bounds<Q: Quantity> { /* private fields */ }Expand description
A set of lower and upper bounds for any metric.
Implementations
Sourceimpl<Q: Quantity> Bounds<Q>
impl<Q: Quantity> Bounds<Q>
Sourcepub fn new(lower: Option<Q>, upper: Option<Q>) -> Self
pub fn new(lower: Option<Q>, upper: Option<Q>) -> Self
Creates a new Bounds with the given lower and upper bounds.
Sourcepub fn combine_parallel(&self, other: &Self) -> Vec<Self>
pub fn combine_parallel(&self, other: &Self) -> Vec<Self>
Combines two bounds as if their components were connected in parallel.
Sourcepub fn intersect(&self, other: &Self) -> Option<Self>
pub fn intersect(&self, other: &Self) -> Option<Self>
Returns the intersection of self and other, or None if the
intersection is empty.
Sourcepub fn merge_if_overlapping(&self, other: &Self) -> Option<Self>
pub fn merge_if_overlapping(&self, other: &Self) -> Option<Self>
If self and other overlap, returns the smallest single interval
that contains both; otherwise returns None.