pub struct LogicalMeterConfig { /* private fields */ }Implementations
Sourceimpl LogicalMeterConfig
impl LogicalMeterConfig
Sourcepub fn new(resampling_interval: TimeDelta) -> Self
pub fn new(resampling_interval: TimeDelta) -> Self
Creates a new LogicalMeterConfig with the given resampling interval.
Sourcepub fn with_default_resampling_function(
self,
function: ResamplingFunction<f32, Sample<f32>>,
) -> Self
pub fn with_default_resampling_function( self, function: ResamplingFunction<f32, Sample<f32>>, ) -> Self
Sets the default resampling function.
This function will be used for all metrics that do not have a specific override set.
If no default resampling function is set, the logical meter will default
to using the Average resampling function.
Sourcepub fn override_resampling_function<M: Metric>(
self,
function: ResamplingFunction<f32, Sample<f32>>,
) -> Self
pub fn override_resampling_function<M: Metric>( self, function: ResamplingFunction<f32, Sample<f32>>, ) -> Self
Sets a resampling function override for a specific metric.
If this function is called multiple times for the same metric, the last function provided will be used.
Sourcepub fn with_max_age_in_intervals(self, max_age_in_intervals: u32) -> Self
pub fn with_max_age_in_intervals(self, max_age_in_intervals: u32) -> Self
Sets the maximum age of samples to be considered for resampling, in number of intervals.
Must be at least 1. If a smaller value is provided, it will be clamped to 1.
If not set, the default value is 3.
Sourcepub fn with_component_graph_config(self, config: ComponentGraphConfig) -> Self
pub fn with_component_graph_config(self, config: ComponentGraphConfig) -> Self
Sets the ComponentGraphConfig forwarded to the underlying graph
when LogicalMeterHandle::try_new (and therefore
Microgrid::try_new) builds it. If not set, the graph crate’s
Default::default() is used.