pub struct Microgrid { /* private fields */ }Expand description
A high-level interface for the Microgrid API.
Implementations
Sourceimpl Microgrid
impl Microgrid
Sourcepub async fn try_new(
url: impl Into<String>,
config: LogicalMeterConfig,
) -> Result<Self, Error>
pub async fn try_new( url: impl Into<String>, config: LogicalMeterConfig, ) -> Result<Self, Error>
Creates a new Microgrid instance with the given microgrid API URL and
logical meter configuration.
The microgrid API connection is established lazily and connection or component-graph build errors during setup are retried indefinitely, so this call blocks until the server is reachable and returns valid data. Returns an error only if the URL is malformed or if the provided logical meter configuration is invalid.
Sourcepub fn new_from_handles(
client: MicrogridClientHandle,
logical_meter: LogicalMeterHandle,
) -> Self
pub fn new_from_handles( client: MicrogridClientHandle, logical_meter: LogicalMeterHandle, ) -> Self
Creates a new Microgrid instance from the given client and logical
meter handles.
Sourcepub fn client(&self) -> MicrogridClientHandle
pub fn client(&self) -> MicrogridClientHandle
Returns a handle to the Microgrid client.
Sourcepub fn logical_meter(&self) -> LogicalMeterHandle
pub fn logical_meter(&self) -> LogicalMeterHandle
Returns a handle to the logical meter.
pub fn battery_pool( &self, component_ids: Option<Vec<u64>>, ) -> Result<BatteryPool, Error>